@@ -1,6 +1,4 @@
-#' @importFrom tidyverse tidyverse_conflicts
-
-core <- c("tidyverse", "mosaic")
+core <- c("mosaic")
 
 # tidyverse:::tidyverse_attach()
 mdsr_attach <- function() {
@@ -9,6 +7,15 @@ mdsr_attach <- function() {
     lapply(core, library, character.only = TRUE, warn.conflicts = FALSE)
 #  )
   
+  packageStartupMessage(
+    paste0("\nIn accordance with CRAN policy, the 'mdsr' package 
+           no longer attaches\nthe 'tidyverse' package automatically.",
+           "\nYou may need to 'library(tidyverse)' in order to 
+           use certain functions."
+    ),
+    appendLF = TRUE)
+  
+  
   invisible()
 }
 
@@ -19,8 +26,6 @@ mdsr_attach <- function() {
     return()
   
   mdsr_attach()
-  
-  x <- tidyverse::tidyverse_conflicts()
 }
 
 is_attached <- function(x) {
